@@ -1,4 +1,4 @@
-/*  $Id: batcher.c,v 1.34.2.1 2003/05/19 02:00:05 rra Exp $
+/*  $Id: batcher.c,v 1.34.2.2 2004/05/17 04:24:53 rra Exp $
 **
 **  Read batchfiles on standard input and spew out batches.
 */
@@ -402,10 +402,9 @@ main(int ac, char *av[])
 	    }
 	}
 
-	/* Write the article.  In case of interrupts, retry the read but
-	 * not the fwrite because we can't check that reliably and
-	 * portably. */
-	if ((fprintf(F, "%s", artdata) == EOF) || ferror(F))
+        /* Write the article.  In case of interrupts, retry the read but not
+           the fwrite because we can't check that reliably and portably. */
+	if ((fwrite(artdata, 1, BytesInArt, F) != BytesInArt) || ferror(F))
 	    break;
 
 	/* Update the counts. */
@@ -423,7 +422,7 @@ main(int ac, char *av[])
 
     if (BATCHopen)
 	BATCHstatus = BATCHclose(F);
-    RequeueAndExit(Cookie, (char *)NULL, 0L);
-    /* NOTREACHED */
+    RequeueAndExit(Cookie, NULL, 0);
+
     return 0;
 }
