@@ -1,4 +1,4 @@
-/*  $Id: cc.c,v 1.107.2.1 2003/05/31 19:48:26 rra Exp $
+/*  $Id: cc.c,v 1.107.2.2 2003/12/29 05:02:53 rra Exp $
 **
 **  Routines for the control channel.
 **
@@ -1317,9 +1317,11 @@ CCreload(char *av[])
     p = av[0];
     if (*p == '\0' || strcmp(p, "all") == 0) {
 	SITEflushall(false);
-	InndHisClose();
+        if (Mode == OMrunning)
+	    InndHisClose();
 	RCreadlist();
-	InndHisOpen();
+	if (Mode == OMrunning)
+	    InndHisOpen();
 	ICDwrite();
 	ICDsetup(true);
 	if (!ARTreadschema())
@@ -1345,6 +1347,8 @@ CCreload(char *av[])
 	ICDsetup(true);
     }
     else if (strcmp(p, "history") == 0) {
+        if (Mode != OMrunning)
+            return CCnotrunning;
 	InndHisClose();
 	InndHisOpen();
     }
