@@ -1,4 +1,4 @@
-/*  $Id: innconf.c,v 1.13 2003/02/03 00:58:24 rra Exp $
+/*  $Id: innconf.c,v 1.13.2.2 2004/05/16 20:18:43 rra Exp $
 **
 **  Manage the global innconf struct.
 **
@@ -375,7 +375,7 @@ innconf_parse(struct config_group *group)
             *string = (char_ptr == NULL) ? NULL : xstrdup(char_ptr);
             break;
         default:
-            die("internal error: invalid type in row %d of config table", i);
+            die("internal error: invalid type in row %u of config table", i);
             break;
         }
     return config;
@@ -405,6 +405,10 @@ innconf_validate(struct config_group *group)
         warn("must set pathnews in inn.conf");
         okay = false;
     }
+    if (innconf->hismethod == NULL) {
+        warn("must set hismethod in inn.conf");
+        okay = false;
+    }
     if (innconf->enableoverview && innconf->ovmethod == NULL) {
         warn("ovmethod must be set in inn.conf if enableoverview is true");
         okay = false;
