@@ -1,4 +1,4 @@
-/*  $Id: buffindexed.c,v 1.76.2.1 2003/05/31 19:48:28 rra Exp $
+/*  $Id: buffindexed.c,v 1.76.2.2 2004/05/20 22:23:28 rra Exp $
 **
 **  Overview buffer and index method.
 */
@@ -2151,7 +2151,7 @@ void buffindexed_close(void) {
   ovbufftab = NULL;
 }
 
-#ifdef DEBUG
+#ifdef BUFF_DEBUG
 static int countgdb(void) {
   int			i, count = 0;
   GROUPDATABLOCK	*gdb;
@@ -2272,4 +2272,4 @@ main(int argc, char **argv) {
     }
   }
 }
-#endif /* DEBUG */
+#endif /* BUFF_DEBUG */
