@@ -1,4 +1,4 @@
-/*  $Id: tradspool.c,v 1.50 2003/03/27 23:56:01 rra Exp $
+/*  $Id: tradspool.c,v 1.50.2.2 2004/12/19 08:19:48 rra Exp $
 **
 **  Storage manager module for traditional spool format.
 */
@@ -957,6 +957,8 @@ tradspool_cancel(TOKEN token) {
     }
 
     if ((xrefs = CrackXref(xrefhdr, &numxrefs)) == NULL || numxrefs == 0) {
+        if (xrefs != NULL)
+            free(xrefs);
 	free(path);
 	tradspool_freearticle(article);
         SMseterror(SMERR_UNDEFINED, NULL);
@@ -1248,7 +1250,7 @@ bool tradspool_ctl(PROBETYPE type, TOKEN *token, void *value) {
     struct artngnum *ann;
     unsigned long ngnum;
     unsigned long artnum;
-    char *ng;
+    char *ng, *p;
 
     switch (type) { 
     case SMARTNGNUM:
@@ -1267,6 +1269,9 @@ bool tradspool_ctl(PROBETYPE type, TOKEN *token, void *value) {
 		return false;
 	}
 	ann->groupname = xstrdup(ng);
+        for (p = ann->groupname; *p != 0; p++)
+            if (*p == '/')
+                *p = '.';
 	ann->artnum = (ARTNUM)artnum;
 	return true;
     default:
